@@ -17,7 +17,6 @@ package casbin
 import (
 	"errors"
 	"fmt"
-	"regexp"
 	"runtime/debug"
 	"strings"
 	"sync"
@@ -31,8 +30,7 @@ import (
 	defaultrolemanager "github.com/casbin/casbin/v2/rbac/default-role-manager"
 	"github.com/casbin/casbin/v2/util"
 
-	"github.com/Knetic/govaluate"
-	"github.com/tidwall/gjson"
+	"github.com/casbin/govaluate"
 )
 
 // Enforcer is the main interface for authorization enforcement and policy management.
@@ -637,7 +635,17 @@ func (e *Enforcer) enforce(matcher string, explains *[]string, rvals ...interfac
 	}
 
 	if e.acceptJsonRequest {
-		expString = requestJsonReplace(expString, rTokens, rvals)
+		// try to parse all request values from json to map[string]interface{}
+		// skip if there is an error
+		for i, rval := range rvals {
+			switch rval := rval.(type) {
+			case string:
+				mapValue, err := util.JsonToMap(rval)
+				if err == nil {
+					rvals[i] = mapValue
+				}
+			}
+		}
 	}
 
 	parameters := enforceParameters{
@@ -685,16 +693,7 @@ func (e *Enforcer) enforce(matcher string, explains *[]string, rvals ...interfac
 					pvals)
 			}
 
-			if e.acceptJsonRequest {
-				pvalsCopy := make([]string, len(pvals))
-				copy(pvalsCopy, pvals)
-				for i, pStr := range pvalsCopy {
-					pvalsCopy[i] = requestJsonReplace(util.EscapeAssertion(pStr), rTokens, rvals)
-				}
-				parameters.pVals = pvalsCopy
-			} else {
-				parameters.pVals = pvals
-			}
+			parameters.pVals = pvals
 
 			result, err := expression.Eval(parameters)
 			// log.LogPrint("Result: ", result)
@@ -796,31 +795,6 @@ func (e *Enforcer) enforce(matcher string, explains *[]string, rvals ...interfac
 	return result, nil
 }
 
-var requestObjectRegex = regexp.MustCompile(`r[_.][A-Za-z_0-9]+\.[A-Za-z_0-9.]+[A-Za-z_0-9]`)
-var requestObjectRegexPrefix = regexp.MustCompile(`r[_.][A-Za-z_0-9]+\.`)
-
-// requestJsonReplace used to support request parameters of type json
-// It will replace the access of the request object in matchers or policy with the actual value in the request json parameter
-// For example: request sub = `{"Owner": "alice", "Age": 30}`
-// policy: p, r.sub.Age > 18, /data1, read  ==>  p, 30 > 18, /data1, read
-// matchers: m = r.sub == r.obj.Owner  ==>  m = r.sub == "alice"
-func requestJsonReplace(str string, rTokens map[string]int, rvals []interface{}) string {
-	matches := requestObjectRegex.FindAllString(str, -1)
-	for _, matchesStr := range matches {
-		prefix := requestObjectRegexPrefix.FindString(matchesStr)
-		jsonPath := strings.TrimPrefix(matchesStr, prefix)
-		tokenIndex := rTokens[prefix[:len(prefix)-1]]
-		if jsonStr, ok := rvals[tokenIndex].(string); ok {
-			newStr := gjson.Get(jsonStr, jsonPath).String()
-			if !util.IsNumeric(newStr) {
-				newStr = `"` + newStr + `"`
-			}
-			str = strings.Replace(str, matchesStr, newStr, -1)
-		}
-	}
-	return str
-}
-
 func (e *Enforcer) getAndStoreMatcherExpression(hasEval bool, expString string, functions map[string]govaluate.ExpressionFunction) (*govaluate.EvaluableExpression, error) {
 	var expression *govaluate.EvaluableExpression
 	var err error
